/***************************************************************************
                          dlg_selectengine.h  -  description
                             -------------------
    begin                : Wed Aug 28 2002
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLG_SELECTENGINE_H
#define DLG_SELECTENGINE_H

#include <tqwidget.h>
#include <kdialogbase.h>
#include "definitions.h"

/**
  *@author Troy Corbin Jr.
  */

class TQVBox;
class TQSlider;
class TQLabel;
class KComboBox;
class TQGroupBox;
class resource;

class dlg_selectengine : public KDialogBase
{
	TQ_OBJECT
  
	public:
										dlg_selectengine(TQWidget *parent, resource *Rsrc, bool army );
										~dlg_selectengine();
		int							strength( void );
		bool						Army;

	protected:
		void						buildEngineData( void );

	protected slots:
		void						slotCurrent( int Index );
		void						slotCurrentHelper( int Index );
		void						slotStrength( int );

	signals:
		void						valuesChanged( void );

	private:
		resource				*Resource;
		int							Engine1F;
		int							Engine2F;

		TQVBox						*BOX_Parent;
		TQGroupBox					*BOX_Engine;
			KComboBox					*COMBO_Engine;
		TQGroupBox					*BOX_EngineHelper;
			KComboBox					*COMBO_EngineHelper;
		TQGroupBox							*GROUP_Strength;
			TQLabel								*LABEL_Str_Min;
			TQSlider								*SLIDER_Strength;
			TQLabel								*LABEL_Str_Max;
};

#endif
